@@ -6,9 +6,11 @@ use std::{
 };
 use url::Url;
 
-mod error_3rd;
-mod error_lsp;
-mod error_std;
+pub(crate) mod diagnostic;
+pub(crate) mod error_3rd;
+#[cfg(feature = "lsp-types")]
+pub(crate) mod error_lsp;
+pub(crate) mod error_std;
 
 pub type Result<T> = std::result::Result<T, YggdrasilError>;
 
